import EnvoyContext from "./envoy-context";
/**
 * this will store the information of a node
 */
export declare class NodeInfo {
    /**
     * the reference count of this info,
     * init will be 1,
     * when this async execution trigger another execution,
     *  this will increase 1,
     * when this execution or one of its child execution is destroyed,
     *  this will decrease 1
     */
    referenceCount: number;
    /**
     * who trigger this async execution
     */
    readonly triggerAsyncId: number;
    /**
     * the context set in this execution
     */
    context?: EnvoyContext;
    constructor(triggerAsyncId: number);
}
/**
 * Eliminate Store
 * using two map for context storage, to avoid holding too many data
 * it will eliminate the old data
 */
export declare class EliminateStore {
    private old;
    private current;
    private lastEliminateTime;
    /**
     * get context
     * @param asyncId asyncId
     */
    get(asyncId: number): NodeInfo | undefined;
    /**
     * set context
     * @param asyncId asyncId
     * @param info context info
     */
    set(asyncId: number, info: NodeInfo): void;
    /**
     * delete context
     * @param asyncId asyncId
     */
    delete(asyncId: number): void;
    /**
     * clear all data
     */
    clear(): void;
    /**
     * eliminate the old data
     */
    eliminate(): void;
    /**
     * get last eliminate time
     */
    getLastEliminateTime(): number;
    /**
     * the current size
     */
    size(): number;
    /**
     * the old store size
     */
    oldSize(): number;
}
declare const _default: {
    enable: () => void;
    disable: () => void;
    set: (context: EnvoyContext) => void;
    get: () => EnvoyContext | undefined;
    isEnabled: () => boolean;
    getStoreImpl: () => EliminateStore;
    getEliminateInterval: () => number;
    setEliminateInterval: (interval: number) => void;
};
export default _default;
